summaryrefslogtreecommitdiffstats
path: root/kexi/formeditor/scripting/scriptIO.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/formeditor/scripting/scriptIO.h')
-rw-r--r--kexi/formeditor/scripting/scriptIO.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/kexi/formeditor/scripting/scriptIO.h b/kexi/formeditor/scripting/scriptIO.h
index 9fed06a6..319de0fd 100644
--- a/kexi/formeditor/scripting/scriptIO.h
+++ b/kexi/formeditor/scripting/scriptIO.h
@@ -20,10 +20,10 @@
#ifndef SCRIPTIO_H
#define SCRIPTIO_H
-#include <qdom.h>
+#include <tqdom.h>
-class QString;
-class QObject;
+class TQString;
+class TQObject;
class Event;
class EventList;
class ScriptManager;
@@ -41,19 +41,19 @@ class ScriptIO
public:
/*! Save the evnts of a form.
Creates an \<events\> tag, and then one \<event\> tag for each event.
- Each event contains \<sender\> and \<receiver\> tags, with attributes depending on event type. */
- static bool saveFormEvents(QDomNode &parentNode, FormScript *script);
- /*! Reads the \<events\> tag (\a parentNode), then creates and fills a FormScript object linked to this \a form.
+ Each event tqcontains \<sender\> and \<receiver\> tags, with attributes depending on event type. */
+ static bool saveFormEvents(TQDomNode &tqparentNode, FormScript *script);
+ /*! Reads the \<events\> tag (\a tqparentNode), then creates and fills a FormScript object linked to this \a form.
The new FormScript object is then added to ScriptManager list.*/
- static bool loadFormEvents(QDomNode &parentNode, Form *form, ScriptManager *manager);
+ static bool loadFormEvents(TQDomNode &tqparentNode, Form *form, ScriptManager *manager);
/*! Save only the events related to widget \a name in the FormScript \a fscript.
Used eg when copying/pasting widgets to keep also events related to it.*/
- static bool saveAllEventsForWidget(QObject *widget, FormScript *fscript, QDomNode &node);
+ static bool saveAllEventsForWidget(TQObject *widget, FormScript *fscript, TQDomNode &node);
- static void saveEvent(Event *event, QDomNode &parentNode);
- static void saveEventList(EventList *list, QDomNode &parentNode);
- static void loadEvent(QDomNode &node, EventList *list, Form *form);
+ static void saveEvent(Event *event, TQDomNode &tqparentNode);
+ static void saveEventList(EventList *list, TQDomNode &tqparentNode);
+ static void loadEvent(TQDomNode &node, EventList *list, Form *form);
protected:
ScriptIO() {;}